componenttools.Lineage
======================

.. abjad-lineage:: abjad.tools.componenttools.Lineage.Lineage.Lineage

.. autoclass:: abjad.tools.componenttools.Lineage.Lineage.Lineage
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.componenttools.Lineage.Lineage.Lineage.component
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Lineage.Lineage.Lineage.music
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Lineage.Lineage.Lineage.start_offset
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Lineage.Lineage.Lineage.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Lineage.Lineage.Lineage.storage_format
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Lineage.Lineage.Lineage.timespan
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.componenttools.Lineage.Lineage.Lineage.__add__
   :noindex:

.. automethod:: abjad.tools.componenttools.Lineage.Lineage.Lineage.__contains__
   :noindex:

.. automethod:: abjad.tools.componenttools.Lineage.Lineage.Lineage.__eq__
   :noindex:

.. automethod:: abjad.tools.componenttools.Lineage.Lineage.Lineage.__ge__
   :noindex:

.. automethod:: abjad.tools.componenttools.Lineage.Lineage.Lineage.__getitem__
   :noindex:

.. automethod:: abjad.tools.componenttools.Lineage.Lineage.Lineage.__gt__
   :noindex:

.. automethod:: abjad.tools.componenttools.Lineage.Lineage.Lineage.__le__
   :noindex:

.. automethod:: abjad.tools.componenttools.Lineage.Lineage.Lineage.__len__
   :noindex:

.. automethod:: abjad.tools.componenttools.Lineage.Lineage.Lineage.__lt__
   :noindex:

.. automethod:: abjad.tools.componenttools.Lineage.Lineage.Lineage.__ne__
   :noindex:

.. automethod:: abjad.tools.componenttools.Lineage.Lineage.Lineage.__radd__
   :noindex:

.. automethod:: abjad.tools.componenttools.Lineage.Lineage.Lineage.__repr__
   :noindex:
